@@ -8,6 +8,12 @@ impl Marker {
     }
 }
 
+impl std::default::Default for Marker {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 /// A Haystack remove marker.
 #[derive(Clone, Debug, Eq, PartialEq)]
 pub struct RemoveMarker;
@@ -17,3 +23,9 @@ impl RemoveMarker {
         Self
     }
 }
+
+impl std::default::Default for RemoveMarker {
+    fn default() -> Self {
+        Self::new()
+    }
+}
