@@ -6,4 +6,10 @@ impl Na {
     pub fn new() -> Self {
         Self
     }
-}
\ No newline at end of file
+}
+
+impl std::default::Default for Na {
+    fn default() -> Self {
+        Self::new()
+    }
+}
